==> nui_core-0.0.21.tar.gz: lib/ui/styling/nui_theme_styling.dart <==
import 'package:animated_theme_switcher/animated_theme_switcher.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/model/nui_theme.dart';

typedef NUIOnThemeChangeListener = void Function(ThemeData theme);
typedef NUIThemeSwitcherInflater = Widget Function(NUIThemeHandler themeHandler);

bool isOnLightTheme(BuildContext context){
  return getCurrentTheme(context) == NUIThemeStyle.LIGHT;
}

bool isOnDarkTheme(BuildContext context){
  return getCurrentTheme(context) == NUIThemeStyle.DARK;
}

NUIThemeStyle getCurrentTheme(BuildContext context){
  try {
    if (ThemeProvider
        .of(context)
        ?.brightness == Brightness.dark) {
      return NUIThemeStyle.DARK;
    }
    return NUIThemeStyle.LIGHT;
  }catch(e){

  }
  return NUIThemeStyle.LIGHT;
}

class NUIThemeHandler{
  NUIThemeHandler._builder();
  NUIOnThemeChangeListener _listener;
  void switchTheme(ThemeData theme){
    if(_listener != null) _listener(theme);
  }
}

class NUIThemeSwitchingScreen extends StatefulWidget {
  NUIThemeSwitchingScreen({@required this.child});
  final Widget child;
  @override
  _NUIThemeSwitchingScreenState createState() => _NUIThemeSwitchingScreenState();
}

class _NUIThemeSwitchingScreenState extends State<NUIThemeSwitchingScreen> {
  @override
  Widget build(BuildContext context) {
    return ThemeSwitchingArea(
        child: Builder(builder: (context) {
          return widget.child;
      }),
    );
  }
}

class NUIThemeSwitcher extends StatefulWidget {
  NUIThemeSwitcher({@required this.child});
  final NUIThemeSwitcherInflater child;
  @override
  _NUIThemeSwitcherState createState() => _NUIThemeSwitcherState();
}

class _NUIThemeSwitcherState extends State<NUIThemeSwitcher> {
  NUIThemeHandler _handler;
  @override
  void initState(){
    super.initState();
    _handler = NUIThemeHandler._builder();
  }

  @override
  Widget build(BuildContext context) {
    return ThemeSwitcher(
      builder: (context) {
        _handler._listener = (ThemeData theme){
          ThemeSwitcher.of(context).changeTheme(theme: theme);
        };
        return widget.child(_handler);
      },
    );
  }
}

==> nui_core-0.0.127.tar.gz: lib/ui/styling/nui_theme_styling.dart <==
import 'package:animated_theme_switcher/animated_theme_switcher.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/model/nui_theme.dart';

typedef NUIOnThemeChangeListener = void Function(ThemeData theme);
typedef NUIThemeSwitcherInflater = Widget Function(NUIThemeHandler themeHandler);

bool isOnLightTheme(BuildContext context){
  return getCurrentTheme(context) == NUIThemeStyle.LIGHT;
}

bool isOnDarkTheme(BuildContext context){
  return getCurrentTheme(context) == NUIThemeStyle.DARK;
}

NUIThemeStyle getCurrentTheme(BuildContext context){
  try {
    if (ThemeProvider.of(context)?.brightness == Brightness.dark) {
      return NUIThemeStyle.DARK;
    }
    return NUIThemeStyle.LIGHT;
  }catch(e){

  }
  return NUIThemeStyle.LIGHT;
}

class NUIThemeHandler{
  NUIThemeHandler._builder();
  NUIOnThemeChangeListener _listener;
  void switchTheme(ThemeData theme){
    if(_listener != null) _listener(theme);
  }
}

class NUIThemeSwitchingScreen extends StatefulWidget {
  NUIThemeSwitchingScreen({@required this.child});
  final Widget child;
  @override
  _NUIThemeSwitchingScreenState createState() => _NUIThemeSwitchingScreenState();
}

class _NUIThemeSwitchingScreenState extends State<NUIThemeSwitchingScreen> {
  @override
  Widget build(BuildContext context) {
    return ThemeSwitchingArea(
        child: Builder(builder: (context) {
          return widget.child;
      }),
    );
  }
}

class NUIThemeSwitcher extends StatefulWidget {
  NUIThemeSwitcher({@required this.child});
  final NUIThemeSwitcherInflater child;
  @override
  _NUIThemeSwitcherState createState() => _NUIThemeSwitcherState();
}

class _NUIThemeSwitcherState extends State<NUIThemeSwitcher> {
  NUIThemeHandler _handler;
  @override
  void initState(){
    super.initState();
    _handler = NUIThemeHandler._builder();
  }

  @override
  Widget build(BuildContext context) {
    return ThemeSwitcher(
      builder: (context) {
        _handler._listener = (ThemeData theme){
          ThemeSwitcher.of(context).changeTheme(theme: theme);
        };
        return widget.child(_handler);
      },
    );
  }
}
